@@ -1,19 +1,23 @@
 """Quickstart command to generate a new project.
 
 Quickstart takes the files from turbogears.quickstart and processes them to produce
-a new, ready-to-run project."""
+a new, ready-to-run project.
 
-import pkg_resources
-import re
+"""
+
+import optparse
 import os
-import os.path
+import re
 import shutil
 import stat
-import optparse
 import sys
+
+import pkg_resources
 import turbogears
+
 from paste.script import templates, create_distro
 
+
 beginning_letter = re.compile(r"^[^a-z]*")
 valid_only = re.compile(r"[^a-z0-9_]")
 
@@ -24,13 +28,6 @@ class TGTemplate(templates.Template):
         vars.setdefault('turbogearsversion',
                 pkg_resources.get_distribution('turbogears').version)
         vars.setdefault('sys_executable', os.path.normpath(sys.executable))
-        # define version-compatible decorator syntax
-        if sys.version_info >= (2, 4):
-            vars['b'] = '@'
-            vars['e'] = ''
-        else:
-            vars['b'] = '['
-            vars['e'] = ']'
         super(TGTemplate, self).run(command, output_dirs, vars)
 
 
@@ -123,6 +120,8 @@ class quickstart:
     sqlobject = False
     elixir = False
     identity = False
+    # we ask user for identity usage in the default settings
+    prompt_identity = True
 
     def __init__(self, version):
         parser = optparse.OptionParser(
@@ -130,35 +129,46 @@ class quickstart:
                     version="%prog " + version)
         parser.add_option("-s", "--sqlalchemy",
             help="use SQLAlchemy instead of SQLObject",
-            action="store_true", dest="sqlalchemy", default = False)
+            action="store_true", dest="sqlalchemy", default=False)
         parser.add_option("-e", "--elixir",
             help="use SQLAlchemy Elixir instead of SQLObject",
-            action="store_true", dest="elixir", default = False)
+            action="store_true", dest="elixir", default=False)
         parser.add_option("-o", "--sqlobject",
             help="use SQLObject instead of SQLAlchemy",
-            action="store_true", dest="sqlobject", default = False)
+            action="store_true", dest="sqlobject", default=False)
         parser.add_option("-i", "--identity",
             help="provide Identity support",
-            action="store_true", dest="identity", default = False)
+            action="store_true", dest="identity", default=False)
+        parser.add_option(
+            "", "--no-identity",
+            help="Don't prompt for Identity support (ignored if -i is on)",
+            action="store_false", dest="prompt_identity", default=True)
         parser.add_option("-p", "--package",
             help="package name for the code",
             dest="package")
         parser.add_option("-t", "--templates",
             help="user specific templates",
-            dest="templates", default = self.templates)
+            dest="templates", default=self.templates)
         parser.add_option("-r", "--svn-repository", metavar="REPOS",
             help="create project in given SVN repository",
-            dest="svn_repository", default = self.svn_repository)
+            dest="svn_repository", default=self.svn_repository)
         parser.add_option("--dry-run",
             help="dry run (don't actually do anything)",
             action="store_true", dest="dry_run")
 
         options, args = parser.parse_args()
         self.__dict__.update(options.__dict__)
+
         if not True in [self.elixir, self.sqlalchemy, self.sqlobject]:
-            self.sqlobject = True
+            self.sqlalchemy = True
+
         if self.elixir:
             self.sqlalchemy = True
+            self.sqlobject = False
+        elif self.sqlalchemy:
+            self.sqlobject = False
+        if self.sqlobject:
+            self.sqlalchemy = False
 
         if args:
             self.name = args[0]
@@ -179,16 +189,20 @@ class quickstart:
                 self.package = package
 
         doidentity = self.identity
-        while not doidentity:
+        while self.prompt_identity and not doidentity:
             doidentity = raw_input("Do you need Identity "
                         "(usernames/passwords) in this project? [no] ")
+
             doidentity = doidentity.lower()
+
             if not doidentity or doidentity.startswith('n'):
-                self.identity="none"
+                self.identity = "none"
                 break
+
             if doidentity.startswith("y"):
                 doidentity = True
                 break
+
             print "Please enter y(es) or n(o)."
             doidentity = None
 
@@ -197,6 +211,9 @@ class quickstart:
                 self.identity = "sqlalchemy"
             else:
                 self.identity = "sqlobject"
+        else:
+            self.identity = "none"
+
         self.name = pkg_resources.safe_name(self.name)
 
         env = pkg_resources.Environment()
@@ -243,7 +260,7 @@ class quickstart:
             sqlalchemyversion = str(get_requirement('sqlalchemy'))
             cmd_args.append("sqlalchemyversion=%s" % sqlalchemyversion)
         if self.elixir:
-            elixirversion = str(get_requirement('future', 'elixir'))
+            elixirversion = str(get_requirement('sqlalchemy', 'elixir'))
             cmd_args.append("elixirversion=%s" % elixirversion)
 
         command.run(cmd_args)
@@ -290,29 +307,29 @@ class update:
     name = None
     templates = "turbogears"
     identity = False
-    sqlalchemy = False
-    sqlobject = True
-    elixir = False
+    sqlalchemy = True
+    sqlobject = False
+    elixir = True
 
     def __init__(self, version):
-        parser = optparse.OptionParser(usage="%prog update [options]",
-                                       version="%prog " + version)
+        self.parser = parser = optparse.OptionParser(usage="%prog update [options]",
+            version="%prog " + version)
         parser.add_option("-s", "--sqlalchemy",
             help="use SQLAlchemy instead of SQLObject",
-            action="store_true", dest="sqlalchemy", default = False)
+            action="store_true", dest="sqlalchemy", default=False)
         parser.add_option("-e", "--elixir",
             help="use SQLAlchemy Elixir instead of SQLObject",
-            action="store_true", dest="elixir", default = False)
+            action="store_true", dest="elixir", default=False)
         parser.add_option("-o", "--sqlobject",
             help="use SQLObject instead of SQLAlchemy",
-            action="store_true", dest="sqlobject", default = True)
+            action="store_true", dest="sqlobject", default=False)
         parser.add_option("-i", "--identity",
             help="provide Identity support",
-            action="store_true", dest="identity", default = False)
+            action="store_true", dest="identity", default=False)
         parser.add_option("-t", "--templates", help="user specific templates",
             dest="templates", default=self.templates)
-        options, args = parser.parse_args()
-        self.__dict__.update(options.__dict__)
+
+        self.turbogearsversion = version
 
     def run(self):
         "Updates an existing project"
@@ -320,8 +337,26 @@ class update:
         self.package = turbogears.util.get_package_name()
         turbogears.command.base.load_project_config()
 
-        if not self.sqlalchemy:
-            if turbogears.config.get('sqlalchemy.dburi'):
+        try:
+            project_dist = pkg_resources.get_distribution(self.name)
+            project_requires = [r.project_name.lower()
+                for r in project_dist.requires()]
+            self.parser.set_defaults(
+                sqlobject = 'sqlobject' in project_requires,
+                sqlalchemy = 'sqlalchemy' in project_requires,
+                elixir = 'elixir' in project_requires)
+        except pkg_resources.DistributionNotFound:
+            print "Could not determine requirements for your application."
+            print "Please run 'python setup.py develop' to make your " + \
+                "application known to setuptools."
+
+        options, args = self.parser.parse_args()
+        self.__dict__.update(options.__dict__)
+
+        if not True in [self.elixir, self.sqlalchemy, self.sqlobject]:
+            if turbogears.config.get('sqlobject.dburi'):
+                self.sqlobject = True
+            else:
                 self.sqlalchemy = True
 
         if self.elixir:
@@ -329,8 +364,8 @@ class update:
             self.sqlobject = False
         elif self.sqlalchemy:
             self.sqlobject = False
-        else:
-            self.sqlobject = True
+        if self.sqlobject:
+            self.sqlalchemy = False
 
         if not self.identity:
             if turbogears.config.get('identity.on'):
@@ -343,9 +378,11 @@ class update:
                 self.identity =  'sqlobject'
         else:
             self.identity = 'none'
+
         currentdir = os.path.basename(os.getcwd())
         if not currentdir == self.name:
-            print 'It looks like your project dir "%s" is named wrongly.' % currentdir
+            print ('It looks like your project directory "%s" is named '
+                'incorrectly.' % currentdir)
             print 'Please rename it to "%s".' % self.name
             return
 
@@ -371,6 +408,10 @@ class update:
             sqlalchemyversion = str(get_requirement('sqlalchemy'))
             cmd_args.append("sqlalchemyversion=%s" % sqlalchemyversion)
 
+        if self.elixir:
+            elixirversion = str(get_requirement('sqlalchemy', 'elixir'))
+            cmd_args.append("elixirversion=%s" % elixirversion)
+
         command.run(cmd_args)
 
         startscript = "start-%s.py" % self.package
