@@ -174,7 +174,7 @@ except ImportError:
 try:
     from genshi.template import MarkupTemplate as GenshiMarkupTemplate
     from genshi.filters.i18n import Translator as GenshiTranslator
-except:
+except ImportError:
     GenshiMarkupTemplate = None
 
 __version__ = '1.5'
@@ -402,10 +402,14 @@ def extract_genshi_strings(filename, options=None):
     if options is None:
         options = {}
 
-    tmpl = open(filename)
-    stream = GenshiMarkupTemplate(tmpl, filename=filename).stream
-    translator = GenshiTranslator(**options)
-    return translator.extract(stream)
+    try:
+        stream = GenshiMarkupTemplate(
+            open(filename), filename=filename, filepath='.').stream
+        translator = GenshiTranslator(**options)
+        return translator.extract(stream)
+    except Exception:
+        print >> sys.stderr, "Extracting from Genshi template", filename
+        raise
 
 
 class TokenEater:
