@@ -24,21 +24,26 @@ def google_translate(from_lang, to_lang, text):
         text = text.encode('utf-8')
     else:
         has_nbsp = False
-    params = urllib.urlencode(dict(client='t',
-        ie='UTF-8', oe='UTF-8', sl=from_lang, tl=to_lang, text=text))
-    text = TGURLopener().open(
-        'http://translate.google.com/translate_a/t', params).read()
-    text = simplejson.loads(text)
-    if isinstance(text, list):
+    params = urllib.urlencode(dict(v='1.0',
+        langpair='%s|%s' % (from_lang, to_lang), q=text))
+    try:
+        result = TGURLopener().open('http://ajax.googleapis.com'
+            '/ajax/services/language/translate', params).read()
+    except IOError:
+        text = None
+    else:
         try:
-            text = text[1][0][1]
-        except IndexError:
+            result = simplejson.loads(result)
+        except ValueError:
+            text = None
+        else:
             try:
-                text = text[0]
-            except IndexError:
-                text = ''
-    if not has_nbsp:
-        text = text.replace(u'\xa0', ' ')
+                text = result['responseData']['translatedText']
+            except (KeyError, TypeError):
+                text = None
+            else:
+                if text and not has_nbsp:
+                    text = text.replace(u'\xa0', ' ')
     return text
 
 def lang_in_gettext_format(lang):
