@@ -1,10 +1,4 @@
-"""The TurboGears identity management package.
-
-@TODO: Laundry list of things yet to be done:
-    * IdentityFilter should support HTTP Digest Auth
-    * Also want to support Atom authentication (similar to digest)
-
-"""
+"""The TurboGears identity management package."""
 
 # declare what should be exported
 __all__ = [
