@@ -7,22 +7,13 @@ import sys
 import tempfile
 import unittest
 
-from datetime import datetime
-
 from turbogears import config
 from turbogears.command.i18n import InternationalizationTool
-from turbogears.i18n.pygettext.pygettext import extract_genshi_strings
-
-try:
-    import kid
-except ImportError:
-    import warnings
-    warnings.warn("Kid is not installed. Omitting i18n test for kid templates.")
-    kid = None
 
 tool = None
 
-KID_TEMPLATE = """\
+
+KID_TEMPLATE = '''\
 <html xmlns:py="http://purl.org/kid/ns#">
 <head>
     <link py:strip="1" py:for="css in tg_css">${css.display()}</link>
@@ -38,9 +29,9 @@ KID_TEMPLATE = """\
   <div>These are some entities that we shouldn't complain about: &nbsp;</div>
 </body>
 </html>
-"""
+'''
 
-GENSHI_TEMPLATE = """\
+GENSHI_TEMPLATE = '''\
 <html xmlns="http://www.w3.org/1999/xhtml"
       xmlns:py="http://genshi.edgewall.org/"
       xmlns:xi="http://www.w3.org/2001/XInclude">
@@ -60,7 +51,7 @@ GENSHI_TEMPLATE = """\
   <div>These are some entities that we shouldn't complain about: &nbsp;</div>
 </body>
 </html>
-"""
+'''
 
 
 class I18nToolTest(unittest.TestCase):
@@ -73,6 +64,10 @@ class I18nToolTest(unittest.TestCase):
         self.src_dir = os.path.join(self.work_dir, 'src')
         self.locale_dir = os.path.join(self.work_dir, 'locale')
         os.mkdir(self.src_dir)
+        self.static_dir = os.path.join(self.src_dir, 'static')
+        os.mkdir(self.static_dir)
+        self.template_dir = os.path.join(self.src_dir, 'templates')
+        os.mkdir(self.template_dir)
         config.update({
             'i18n.locale_dir': self.locale_dir,
             'i18n.domain': 'testmessages',
@@ -87,7 +82,7 @@ class I18nToolTest(unittest.TestCase):
 
     def test_collect_js_strings_utf8(self):
         """Strings from JS files with non-ascii chars (UTF-8) are collected correctly"""
-        js_file = os.path.join(self.src_dir, "utf8.js")
+        js_file = os.path.join(self.static_dir, "utf8.js")
         tf = open(js_file, "w")
         tf.write(u"msg = _('Schöne Grüße')".encode('utf-8'))
         tf.close()
@@ -105,7 +100,7 @@ class I18nToolTest(unittest.TestCase):
 
     def test_collect_js_strings_latin1(self):
         """Strings from JS files with non-ascii chars (Latin-1) are collected correctly"""
-        js_file = os.path.join(self.src_dir, "utf8.js")
+        js_file = os.path.join(self.static_dir, "utf8.js")
         tf = open(js_file, "w")
         tf.write(u"msg = _('Schöne Grüße')".encode('latin1'))
         tf.close()
@@ -123,7 +118,7 @@ class I18nToolTest(unittest.TestCase):
 
     def test_collect_genshi_strings(self):
         """Strings from Genshi templates are collected correctly."""
-        tf = open(os.path.join(self.src_dir, "test.html"), "w")
+        tf = open(os.path.join(self.template_dir, "test.html"), "w")
         tf.write(GENSHI_TEMPLATE)
         tf.close()
         assert not os.path.isdir(self.locale_dir), "locale directory should not exist yet"
@@ -140,22 +135,28 @@ class I18nToolTest(unittest.TestCase):
         assert "it shouldn't be collected" not in pot_content
         assert "es sollte nicht aufgesammelt werden" not in pot_content
 
-    if kid:
-        def test_collect_kid_strings(self):
-            """Strings from kid templates are collected correctly."""
-            tf = open(os.path.join(self.src_dir, "test.kid"), "w")
-            tf.write(KID_TEMPLATE)
-            tf.close()
-            assert not os.path.isdir(self.locale_dir), "locale directory should not exist yet"
-            sys.argv = ['i18n.py', '--src-dir', self.src_dir, 'collect']
-            tool.load_config = False
-            tool.run()
-            assert os.path.isdir(self.locale_dir), "locale directory not created"
-            tf = open(os.path.join(self.locale_dir, "testmessages.pot"))
-            pot_content = tf.read()
-            tf.close()
-            assert "Some text to be i18n'ed" in pot_content
-            assert "kid expression in attribute" in pot_content
-            assert "normal attribute text" not in pot_content
-            assert "it shouldn't be collected" not in pot_content
-            assert "es sollte nicht aufgesammelt werden" not in pot_content
+    def test_collect_kid_strings(self):
+        """Strings from Kid templates are collected correctly."""
+        try:
+            import kid
+        except ImportError:
+            import warnings
+            warnings.warn("Kid is not installed."
+                " Omitting i18n test for Kid templates.")
+            return
+        tf = open(os.path.join(self.template_dir, "test.kid"), "w")
+        tf.write(KID_TEMPLATE)
+        tf.close()
+        assert not os.path.isdir(self.locale_dir), "locale directory should not exist yet"
+        sys.argv = ['i18n.py', '--src-dir', self.src_dir, 'collect']
+        tool.load_config = False
+        tool.run()
+        assert os.path.isdir(self.locale_dir), "locale directory not created"
+        tf = open(os.path.join(self.locale_dir, "testmessages.pot"))
+        pot_content = tf.read()
+        tf.close()
+        assert "Some text to be i18n'ed" in pot_content
+        assert "kid expression in attribute" in pot_content
+        assert "normal attribute text" not in pot_content
+        assert "it shouldn't be collected" not in pot_content
+        assert "es sollte nicht aufgesammelt werden" not in pot_content
