@@ -6,18 +6,14 @@ __email__ = "ronald@checkandhsare.com"
 __copyright__ = "Copyright 2005 Ronald Jaramillo"
 __license__ = "MIT"
 
-from browse import Browse
 import cPickle as pickle
 import datetime
+import decimal
 import os
 import re
 import socket
 import struct
 import time
-try:
-    import decimal
-except ImportError:
-    decimal = None
 
 import pkg_resources
 
@@ -31,6 +27,7 @@ except ImportError:
 import turbogears
 from turbogears import config, expose, identity
 
+from browse import Browse
 
 date_parser = re.compile(r"""^
     (?P<year>\d{4,4})
@@ -271,7 +268,7 @@ class CatWalk(turbogears.controllers.Controller):
         """Loop trough the columns and extract the values from the dictionary.
 
         @param cols: column list
-        @param values: dict of submited values
+        @param values: dict of submitted values
 
         """
         params = {}
@@ -333,22 +330,13 @@ class CatWalk(turbogears.controllers.Controller):
                 return None
 
     def extract_decimal_value(self, value, not_none):
-        if decimal:
-            try:
-                return decimal.Decimal(value)
-            except (TypeError, ValueError, decimal.InvalidOperation):
-                if not_none:
-                    return decimal.Decimal('0.0')
-                else:
-                    return None
-        else:
-            try:
-                return float(value)
-            except ValueError:
-                if not_none:
-                    return 0.0
-                else:
-                    return None
+        try:
+            return decimal.Decimal(value)
+        except (TypeError, ValueError, decimal.InvalidOperation):
+            if not_none:
+                return decimal.Decimal('0.0')
+            else:
+                return None
 
     def object_instances(self, object_name, start=0):
         """Return dictionary containing all instances for the requested object.
@@ -508,7 +496,7 @@ class CatWalk(turbogears.controllers.Controller):
 
         Depending on the column type the properties returned could be:
         type, title, join (otherClassName), joinMethodName,
-        length, varchar,labelColumn,opetions
+        length, varchar, labelColumn, options
 
         @param column_name: name of the column
         @type column_name: string
@@ -609,7 +597,7 @@ class CatWalk(turbogears.controllers.Controller):
 
         By default this is located in a directory named 'catwalk-session'
         beneath your application's package directory or, if the package name
-        can not be determined, below the ccurrent directory.
+        can not be determined, below the current directory.
 
         The directory must be writable by the server and will be created if it
         does not exist. You can specify a different directory if you set the
@@ -722,8 +710,8 @@ class CatWalk(turbogears.controllers.Controller):
     def load_column_order(self, object_name):
         """Get the column order.
 
-        If the user has rearrenged the columns order for an object,
-        this will return the prefered order as list.
+        If the user has rearranged the columns order for an object,
+        this will return the preferred order as list.
 
         @param object_name: name of the object
         @type object_name: string
@@ -734,7 +722,7 @@ class CatWalk(turbogears.controllers.Controller):
         return cols.get(object_name, [])
 
     def save_column_order(self, object_name, columns_bsv):
-        """Save the prefered order of the object's columns.
+        """Save the preferred order of the object's columns.
 
         @param object_name: name of the object
         @type object_name: string
@@ -749,7 +737,7 @@ class CatWalk(turbogears.controllers.Controller):
         self.save_state(state)
 
     def order_columns(self, object_name, cols):
-        """Return a rearrenged list of columns as configured by the user.
+        """Return a rearranged list of columns as configured by the user.
 
         @param object_name: name of the object
         @type object_name: string
@@ -803,7 +791,7 @@ class CatWalk(turbogears.controllers.Controller):
     def add(self, **v):
         """Create a new instance of an object.
 
-        @param v: dictionary of submited values
+        @param v: dictionary of submitted values
 
         """
         objectName = v['objectName']
@@ -885,13 +873,13 @@ class CatWalk(turbogears.controllers.Controller):
 
     @expose(format="json")
     def saveModelOrder(self, models):
-        """Save the prefered order of the listed models."""
+        """Save the preferred order of the listed models."""
         self.save_model_order(models)
         return '' #return dummy string, else json will barf
 
     @expose(format="json")
     def columnOrder(self, objectName, cols):
-        """Save the prefered order of the object's columns.
+        """Save the preferred order of the object's columns.
 
         @param objectName: name of the object
         @type objectName: string
@@ -900,8 +888,7 @@ class CatWalk(turbogears.controllers.Controller):
 
         """
         self.save_column_order(objectName, cols)
-        """return dummy string, else json will barf"""
-        return ''
+        return '' # return dummy string, else json will barf
 
     @expose(format="json")
     def instances(self, objectName, start=0):
@@ -921,7 +908,7 @@ class CatWalk(turbogears.controllers.Controller):
             join, relatedObjectName, **vargs):
         """Get related joins.
 
-        Returns a JSON structure whith a list of related joins for
+        Returns a JSON structure with a list of related joins for
         the requested object, and a list of all joins.
 
         @param objectName: name of the object
@@ -944,7 +931,7 @@ class CatWalk(turbogears.controllers.Controller):
             join, joinType, joinObjectName, joins):
         """Update joins.
 
-        Drop all related joins first, then loop trought the submited joins
+        Drop all related joins first, then loop trough the submitted joins
         and set the relation.
 
         @param objectName: name of the object
@@ -957,7 +944,7 @@ class CatWalk(turbogears.controllers.Controller):
         @type joinType: string
         @param joinObjectName: name of the joined object (otherClassName)
         @type joinObjectName: string
-        @param joins: coma delimited string of join instances id's
+        @param joins: comma delimited string of join instances id's
         @type joins: string
 
         """
@@ -1184,7 +1171,7 @@ class CatWalk(turbogears.controllers.Controller):
         """Return JSON structure containing a list of available objects."""
         return dict(SQLObjects=self.models())
 
-    @expose(template='kid:turbogears.toolbox.catwalk.catwalk')
+    @expose(template='turbogears.toolbox.catwalk.catwalk')
     def index(self):
         """Main CatWalk page.
 
