@@ -8,44 +8,39 @@ else:
     from sqlobject.sqlbuilder import Select, func, AND, IN
 
 import turbogears
-from turbogears import expose
+from turbogears import expose, controllers
 
 
-class Browse(object):
+class Browse(controllers.Controller):
 
     def __getattr__(self, attrib):
         """Delegate basic methods to CatWalk."""
         return getattr(self.catwalk, attrib)
 
-    def list_view(sql_class_name, page_size=10, offset=10,
-            fields=[], filters=[], sort_by=None):
-        pass
-
-    [expose(template='turbogears.toolbox.catwalk.browse_grid', allow_json=True)]
+    @expose(template='turbogears.toolbox.catwalk.browse_grid', allow_json=True)
     def index(self, object_name, start=0, page_size=10,
             context='', filters=''):
-        total = 0
-        headers = []
-        rows = []
-        start = int(start)
-        page_size = int(page_size)
+        try:
+            start, page_size = int(start), int(page_size)
+        except ValueError:
+            start, page_size = 0, 10
         if not context:
             context = object_name
-        headers = self.column_headers(object_name, context)
-        headers = [header for header in headers if header['visible']]
+        headers = [header for header in self.column_headers(
+            object_name, context) if header['visible']]
         total, rows = self.rows_for_model(
             object_name, start, page_size, filters)
         return dict(object_name=object_name, start=start, page_size=page_size,
             total=total, headers= headers, rows = rows)
 
-    [expose(template='turbogears.toolbox.catwalk.columns', allow_json=True)]
+    @expose(template='turbogears.toolbox.catwalk.columns', allow_json=True)
     def columns(self, object_name, context=''):
         if not context:
             context = object_name
         return dict(object_name=object_name, context = context,
             columns=self.extended_column_headers(object_name, context))
 
-    [expose(allow_json=True)]
+    @expose(allow_json=True)
     def save_columns(self, object_name, context, order, hidden_columns,
             updated_fk_labels):
         self.save_column_order(context, order)
@@ -210,8 +205,14 @@ class Browse(object):
         return fk_values
 
     def join_foreign_key(self, column):
-        foreign_key = '%sID' % column.joinColumn.split('_')[0]
-        return getattr(column.otherClass.q, foreign_key)
+        try:
+            foreign_key = '%sID' % column.joinColumn.rsplit('_', 1)[0]
+            return getattr(column.otherClass.q, foreign_key)
+        except AttributeError:
+            raise AttributeError("Key %r in %s pointing to %s not found.\n"
+                "You may need to rename it or use the joinColumn argument."
+                % (foreign_key,
+                   column.otherClass.__name__, column.soClass.__name__,))
 
     def column_label_options(self, column):
         foreign_key_labels = [{'name': 'id', 'title': '#'}]
@@ -252,7 +253,7 @@ class Browse(object):
     def merge_relation_values(self, rows, relations):
         for field_name in relations:
             for id, value in relations[field_name]:
-                if not rows.has_key(id):
+                if id not in rows:
                     continue
                 rows[id][field_name] = self.encode_label(value)
         keys = rows.keys()
@@ -272,7 +273,9 @@ class Browse(object):
 
     def field_value(self, result, column):
         value = getattr(result, column.name)
-        return self.encode_label(value)
+        if value is not None:
+            value = self.encode_label(value)
+        return value
 
     def fields(self, object_name, result):
         obj = self.load_object(object_name)
