@@ -38,7 +38,7 @@ def version_file(file_spec, vtype='copy'):
     if os.path.isfile(file_spec):
         # check the 'vtype' parameter
         if vtype not in ('copy', 'rename'):
-            raise ValueError, 'Unknown vtype %r' % (vtype,)
+            raise ValueError('Unknown vtype %r' % (vtype,))
 
         # determine root file name so the extension doesn't get longer and longer...
         n, e = os.path.splitext(file_spec)
@@ -60,7 +60,7 @@ def version_file(file_spec, vtype='copy'):
                 else:
                     os.rename(file_spec, new_file)
                 return True
-        raise RuntimeError, "Can't %s %r, all names taken" % (vtype, file_spec)
+        raise RuntimeError("Can't %s %r, all names taken" % (vtype, file_spec))
     return False
 
 
@@ -85,8 +85,10 @@ class Designer(controllers.RootController):
 
     def __init__(self):
         if not sqlobject:
-            raise ImportError, ("Cannot run the Model Designer.\n"
+            raise ImportError("Cannot run the Model Designer.\n"
                 "The SQLObject package is not installed.")
+        self.register_static_directory()
+        self.model = self.get_model_name()
 
     def set_model(self, model):
         self.model = model
@@ -97,12 +99,11 @@ class Designer(controllers.RootController):
         return get_model()
 
     def register_static_directory(self):
-        static_directory = pkg_resources.resource_filename(__name__,'static')
-        turbogears.config.update({ '/tg_toolbox/designer': {
+        static_directory = pkg_resources.resource_filename(__name__, 'static')
+        turbogears.config.update({'/tg_toolbox/designer': {
             'static_filter.on': True,
             'static_filter.dir': static_directory}})
 
-
     def column_type(self, column):
         """Given a column representation return the column type."""
         column_type = '%r' % column
@@ -263,12 +264,10 @@ class Designer(controllers.RootController):
             return False, 'Failed to save %s' % model_path
 
     def save_and_create_(self, code, order):
-        model_path = os.path.join(get_project_name(),
-            'tmp2_model.py')
+        model_path = os.path.join(get_project_name(), 'tmp2_model.py')
         model_path = os.path.abspath(model_path)
         open(model_path, 'w').write(str)
-        package = __import__(get_package_name(), {}, {},
-            ["tmp2_model"])
+        package = __import__(get_package_name(), {}, {}, ['tmp2_model'])
         package.tmp2_model.Persona.createTable(ifNotExists=True)
         model = self.get_model_name()
         model.Persona = package.tmp2_model.Persona
@@ -293,8 +292,7 @@ class Designer(controllers.RootController):
             return dict(status='Failed to create a temporary model file: %s' % e)
 
         model = self.get_model_name()
-        package = __import__(get_package_name(), {}, {},
-            [tmp_name])
+        package = __import__(get_package_name(), {}, {}, [tmp_name])
         tmp_model = getattr(package, tmp_name)
 
         ok = []
@@ -355,14 +353,9 @@ class Designer(controllers.RootController):
     def session_list(self):
         return dict(models=self.load_session_list())
 
-    @expose(template='kid:%s.modelDesigner' % baseTemplate)
+    @expose(template='%s.modelDesigner' % baseTemplate)
     def index(self):
-        self.register_static_directory()
-        self.model = self.get_model_name()
-        model_exists = None
-        if self.model:
-            model_exists = 1
-        return dict(model_exists=model_exists,
-            session_file_exists = self.session_exists(),
-            session_list = self.load_session_list(),
+        return dict(model_exists=bool(self.model),
+            session_file_exists=self.session_exists(),
+            session_list=self.load_session_list(),
             model_name=get_project_name())
