@@ -40,7 +40,7 @@ def test_rendering_without_engine():
     else:
         msg = 'No error'
     view.engines = engines
-    assert 'templating engine is not yet loaded' in msg
+    assert 'templating engine is not installed or not yet loaded' in msg
 
 def test_label():
     """Tests simple labels"""
